@@ -49,21 +49,21 @@
 
 // DDD includes
 #include "ArgField.h"
-#include "BoxSize.h"
+#include "box/BoxSize.h"
 #include "Command.h"
-#include "Delay.h"
-#include "ExitCB.h"
+#include "x11/Delay.h"
+#include "x11/ExitCB.h"
 #include "GDBAgent.h"
-#include "GraphEdit.h"
+#include "graph/GraphEdit.h"
 #include "HelpCB.h"
 #include "IntArray.h"
-#include "MString.h"
-#include "MakeMenu.h"
-#include "StringA.h"
-#include "VSEFlags.h"
-#include "VSLLib.h"
-#include "events.h"
-#include "strclass.h"
+#include "motif/MString.h"
+#include "motif/MakeMenu.h"
+#include "template/StringA.h"
+#include "vslsrc/VSEFlags.h"
+#include "vslsrc/VSLLib.h"
+#include "x11/events.h"
+#include "base/strclass.h"
 #include "string-fun.h"
 
 
