@@ -1,12 +1,14 @@
-"#line 1 \"ddd.vsl\"\n"
-"#line 1 \"<built-in>\"\n"
-"#line 1 \"<command-line>\"\n"
+"# 0 \"tmp.c\"\n"
+"# 0 \"<built-in>\"\n"
+"# 0 \"<command-line>\"\n"
+"#line 1 \"/usr/include/stdc-predef.h\"\n"
+"# 0 \"<command-line>\" 2\n"
 "#line 1 \"ddd.vsl\"\n"
 "#line 30 \"ddd.vsl\"\n"
-"#line 1 \"./../vsllib/std.vsl\"\n"
-"#line 28 \"./../vsllib/std.vsl\"\n"
-"#line 1 \"./../vsllib/builtin.vsl\"\n"
-"#line 31 \"./../vsllib/builtin.vsl\"\n"
+"#line 1 \"../../ddd/ddd/../vsllib/std.vsl\"\n"
+"#line 28 \"../../ddd/ddd/../vsllib/std.vsl\"\n"
+"#line 1 \"../../ddd/ddd/../vsllib/builtin.vsl\"\n"
+"#line 31 \"../../ddd/ddd/../vsllib/builtin.vsl\"\n"
 "__op_halign(...);\n"
 "__op_valign(...);\n"
 "__op_ualign(...);\n"
@@ -95,7 +97,7 @@
 "fail() = __fail();\n"
 "fail(message) = __fail(message);\n"
 "undef() = __undef();\n"
-"#line 29 \"./../vsllib/std.vsl\"\n"
+"#line 29 \"../../ddd/ddd/../vsllib/std.vsl\"\n"
 "\n"
 "\n"
 "std_version() = \"$Id$\";\n"
@@ -293,12 +295,12 @@
 "squote() = \"'\";\n"
 "copyright() = \"(c)\";\n"
 "#line 31 \"ddd.vsl\"\n"
-"#line 1 \"./../vsllib/tab.vsl\"\n"
-"#line 28 \"./../vsllib/tab.vsl\"\n"
-"#line 1 \"./../vsllib/std.vsl\"\n"
-"#line 28 \"./../vsllib/std.vsl\"\n"
-"#line 1 \"./../vsllib/builtin.vsl\"\n"
-"#line 31 \"./../vsllib/builtin.vsl\"\n"
+"#line 1 \"../../ddd/ddd/../vsllib/tab.vsl\"\n"
+"#line 28 \"../../ddd/ddd/../vsllib/tab.vsl\"\n"
+"#line 1 \"../../ddd/ddd/../vsllib/std.vsl\"\n"
+"#line 28 \"../../ddd/ddd/../vsllib/std.vsl\"\n"
+"#line 1 \"../../ddd/ddd/../vsllib/builtin.vsl\"\n"
+"#line 31 \"../../ddd/ddd/../vsllib/builtin.vsl\"\n"
 "__op_halign(...);\n"
 "__op_valign(...);\n"
 "__op_ualign(...);\n"
@@ -387,7 +389,7 @@
 "fail() = __fail();\n"
 "fail(message) = __fail(message);\n"
 "undef() = __undef();\n"
-"#line 29 \"./../vsllib/std.vsl\"\n"
+"#line 29 \"../../ddd/ddd/../vsllib/std.vsl\"\n"
 "\n"
 "\n"
 "std_version() = \"$Id$\";\n"
@@ -584,11 +586,11 @@
 "dquote() = \"\\\"\";\n"
 "squote() = \"'\";\n"
 "copyright() = \"(c)\";\n"
-"#line 29 \"./../vsllib/tab.vsl\"\n"
+"#line 29 \"../../ddd/ddd/../vsllib/tab.vsl\"\n"
 "\n"
 "\n"
 "tab_version() = \"$Id$\";\n"
-"#line 46 \"./../vsllib/tab.vsl\"\n"
+"#line 46 \"../../ddd/ddd/../vsllib/tab.vsl\"\n"
 "tab_elem([]) = tab_elem(0);\n"
 "tab_elem(x) = whiteframe(x);\n"
 "\n"
@@ -670,8 +672,8 @@
 "| _dtab(_tab_width(...), ...)\n"
 "| hrule();\n"
 "#line 32 \"ddd.vsl\"\n"
-"#line 1 \"./../vsllib/fonts.vsl\"\n"
-"#line 29 \"./../vsllib/fonts.vsl\"\n"
+"#line 1 \"../../ddd/ddd/../vsllib/fonts.vsl\"\n"
+"#line 29 \"../../ddd/ddd/../vsllib/fonts.vsl\"\n"
 "fonts_version() = \"$Id$\";\n"
 "\n"
 "\n"
@@ -803,20 +805,20 @@
 "sl(...) = it(...);\n"
 "bs(...) = bi(...);\n"
 "#line 33 \"ddd.vsl\"\n"
-"#line 1 \"./../vsllib/colors.vsl\"\n"
-"#line 29 \"./../vsllib/colors.vsl\"\n"
+"#line 1 \"../../ddd/ddd/../vsllib/colors.vsl\"\n"
+"#line 29 \"../../ddd/ddd/../vsllib/colors.vsl\"\n"
 "colors_version() = \"$Id$\";\n"
 "\n"
 "\n"
 "color(box, fg, bg) = foreground(background(box, bg), fg);\n"
 "color(box, fg) = foreground(box, fg);\n"
 "#line 34 \"ddd.vsl\"\n"
-"#line 1 \"./../vsllib/list.vsl\"\n"
-"#line 28 \"./../vsllib/list.vsl\"\n"
-"#line 1 \"./../vsllib/std.vsl\"\n"
-"#line 28 \"./../vsllib/std.vsl\"\n"
-"#line 1 \"./../vsllib/builtin.vsl\"\n"
-"#line 31 \"./../vsllib/builtin.vsl\"\n"
+"#line 1 \"../../ddd/ddd/../vsllib/list.vsl\"\n"
+"#line 28 \"../../ddd/ddd/../vsllib/list.vsl\"\n"
+"#line 1 \"../../ddd/ddd/../vsllib/std.vsl\"\n"
+"#line 28 \"../../ddd/ddd/../vsllib/std.vsl\"\n"
+"#line 1 \"../../ddd/ddd/../vsllib/builtin.vsl\"\n"
+"#line 31 \"../../ddd/ddd/../vsllib/builtin.vsl\"\n"
 "__op_halign(...);\n"
 "__op_valign(...);\n"
 "__op_ualign(...);\n"
@@ -905,7 +907,7 @@
 "fail() = __fail();\n"
 "fail(message) = __fail(message);\n"
 "undef() = __undef();\n"
-"#line 29 \"./../vsllib/std.vsl\"\n"
+"#line 29 \"../../ddd/ddd/../vsllib/std.vsl\"\n"
 "\n"
 "\n"
 "std_version() = \"$Id$\";\n"
@@ -1102,7 +1104,7 @@
 "dquote() = \"\\\"\";\n"
 "squote() = \"'\";\n"
 "copyright() = \"(c)\";\n"
-"#line 29 \"./../vsllib/list.vsl\"\n"
+"#line 29 \"../../ddd/ddd/../vsllib/list.vsl\"\n"
 "\n"
 "\n"
 "list_version() = \"$Id$\";\n"
@@ -1270,6 +1272,7 @@
 "list_color(box) = color(box, \"black\");\n"
 "array_color(box) = color(box, \"blue4\");\n"
 "reference_color(box) = color(box, \"blue4\");\n"
+"stl_vector_color(box) = color(box, \"blue4\");\n"
 "changed_color(box) = color(box, \"black\", \"#ffffcc\");\n"
 "shadow_color(box) = color(box, \"grey\");\n"
 "\n"
@@ -1449,6 +1452,14 @@
 "reference_color(vcenter(value_rm(\"...\") & hfill()));\n"
 "\n"
 "\n"
+"stl_vector_value (para, value) ->\n"
+"stl_vector_color(value_rm(para & \": \") & value & hfill());\n"
+"\n"
+"\n"
+"collapsed_stl_vector_value () ->\n"
+"stl_vector_color(value_rm(\"...\") & hfill());\n"
+"\n"
+"\n"
 "changed_value (value) ->\n"
 "changed_color(value_it(value));\n"
 "\n"
